==> tecfy_core_package-1.0.51.tar.gz: lib/views/components/country_dropdown.dart <==
part of tecfy_core_client_package;

class CountryDropdownComponent extends StatefulWidget {
  final String value;
  final dynamic onSelect;
  CountryDropdownComponent(this.value, this.onSelect);
  @override
  _CountryDropdownComponentState createState() =>
      _CountryDropdownComponentState();
}

class _CountryDropdownComponentState extends State<CountryDropdownComponent> {
  late String _selectedValue;

  @override
  initState() {
    _selectedValue = widget.value;
    if (_selectedValue.isEmpty) _selectedValue = 'Australia';
    super.initState();
  }

  _onSelected(String? item) {
    AppNavigator.hapticFeedback(heavy: false);

    _selectedValue = item ?? '';
    widget.onSelect(item);
    setState(() {});
  }

  _onSelectedIos(int item) {
    //selectedValue = item;
    //widget.onSelect(item);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: <Widget>[
        SizedBox(
          height: 5.0,
        ),
        Text('Country', style: TextStyle(fontSize: 12.0)),
        StreamBuilder<List<String>>(
          // stream: CountryService().getCountries(),
          builder: (_, snap) {
            if (!snap.hasData)
              return CircularProgressIndicator(
                  valueColor:
                      AlwaysStoppedAnimation<Color>(ThemeService.mainColor));
            return DropdownButtonHideUnderline(
                child: DropdownButton<String>(
              items: snap.data
                      ?.map((c) => DropdownMenuItem<String>(
                            child: Padding(
                                padding: EdgeInsets.only(left: 6),
                                child: Text(c,
                                    style: TextStyle(
                                        color: c == _selectedValue
                                            ? null
                                            : ThemeService.secondryColor))),
                            value: c,
                          ))
                      .toList() ??
                  [],
              onChanged: _onSelected,
              hint: Text('Select Your Country'),
              value: (snap.data?.any((c) => c == _selectedValue) ?? false)
                  ? _selectedValue
                  : 'Australia',
            ));
          },
          //
        ),
        Container(height: 1.0, color: Colors.black),
        SizedBox(height: 15.0)
      ],
    );
  }
}

==> tecfy_core_package-1.1.25.tar.gz: lib/views/components/country_dropdown.dart <==
part of tecfy_core_client_package;

class CountryDropdownComponent extends StatefulWidget {
  final String value;
  final dynamic onSelect;
  CountryDropdownComponent(this.value, this.onSelect);
  @override
  _CountryDropdownComponentState createState() =>
      _CountryDropdownComponentState();
}

class _CountryDropdownComponentState extends State<CountryDropdownComponent> {
  late String _selectedValue;

  @override
  initState() {
    _selectedValue = widget.value;
    if (_selectedValue.isEmpty) _selectedValue = 'Australia';
    super.initState();
  }

  _onSelected(String? item) {
    AppNavigator.hapticFeedback(heavy: false);

    _selectedValue = item ?? '';
    widget.onSelect(item);
    setState(() {});
  }

  _onSelectedIos(int item) {
    //selectedValue = item;
    //widget.onSelect(item);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: <Widget>[
        SizedBox(
          height: 5.0,
        ),
        TecfyText('Country', style: TextStyle(fontSize: 12.0)),
        StreamBuilder<List<String>>(
          // stream: CountryService().getCountries(),
          builder: (_, snap) {
            if (!snap.hasData)
              return CircularProgressIndicator(
                  valueColor:
                      AlwaysStoppedAnimation<Color>(ThemeService.mainColor));
            return DropdownButtonHideUnderline(
                child: DropdownButton<String>(
              items: snap.data
                      ?.map((c) => DropdownMenuItem<String>(
                            child: Padding(
                                padding: EdgeInsets.only(left: 6),
                                child: TecfyText(c,
                                    style: TextStyle(
                                        color: c == _selectedValue
                                            ? null
                                            : ThemeService.secondryColor))),
                            value: c,
                          ))
                      .toList() ??
                  [],
              onChanged: _onSelected,
              hint: TecfyText('Select Your Country'),
              value: (snap.data?.any((c) => c == _selectedValue) ?? false)
                  ? _selectedValue
                  : 'Australia',
            ));
          },
          //
        ),
        Container(height: 1.0, color: Colors.black),
        SizedBox(height: 15.0)
      ],
    );
  }
}
